@@ -5,12 +5,13 @@ import getpass
 
 class MongoSession:
 
-    def __init__(self, host, user=None, password=None, key=None, port=22, to_host='127.0.0.1', to_port=27017):
+    def __init__(self, host, user=None, password=None, key=None, uri=None, port=22, to_host='127.0.0.1', to_port=27017):
 
         HOST = (host, port)
         USER = user or getpass.getuser()
         KEY = key or f'/home/{USER}/.ssh/id_rsa'
         self.to_host = to_host
+        self.uri = uri
 
         if password:
             self.server = SSHTunnelForwarder(
@@ -31,7 +32,10 @@ class MongoSession:
 
     def start(self):
         self.server.start()
-        self.connection = pymongo.MongoClient(self.to_host, self.server.local_bind_port)
+        if self.uri:
+            self.connection = pymongo.MongoClient(self.uri)
+        else:
+            self.connection = pymongo.MongoClient(self.to_host, self.server.local_bind_port)
 
     def stop(self):
         self.connection.close()
